/*
 * Test block server access to memory cards.
 *
 * Copyright (C) 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/sys/err.h>
#include <fsclient/client.h>
#include <systypes/fcntl.h>

#include <stdint.h>
#include <stdio.h>



static int show_sector(file_t *device)
{
  uint8_t sector[512];

  printf("Seek...\n");
  client_seek(device, 1024, SEEK_SET);

  printf("Read...\n");
  offset_t nread = client_read(device, sector, 512);
  int row, col;

  if (!nread)
  {
    printf("Could not read sector.\n");
    return 1;
  }

  for (row = 0; row < 512; row += 16)
  {
    printf("%04x:", row);

    for (col = 0; col < 16; col++)
      printf(" %02x", sector[row + col]);

    printf("\n");
  }

  return 0;
}



int main(int argc, char *argv[])
{
  if (argc < 1)
  {
    printf("Need a partition number.\n");
    return 1;
  }

  /* Obtain filename and access parameters. */

  char *filename = argv[1];
  file_t *file;

  file = client_open(filename, O_RDONLY);

  if (!client_opened(file))
  {
    printf("Could not obtain file: %s\n", file != NULL ? l4sys_errtostr(file->error) : "(null)");
    return 1;
  }

  printf("Opened file: %s\n", filename);

  show_sector(file);
  
  client_close(file);
  printf("End of test.\n");
  return 0;
}

// vim: tabstop=2 expandtab shiftwidth=2
